#
# spec file for package mariadb-connector-odbc
#
# Copyright (c) 2018 SUSE LINUX GmbH, Nuernberg, Germany.
#
# All modifications and additions to the file contributed by third parties
# remain the property of their copyright owners, unless otherwise agreed
# upon. The license for this file, and modifications and additions to the
# file, is the same license as for the pristine package itself (unless the
# license for the pristine package is not an Open Source License, in which
# case the license is the MIT License). An "Open Source License" is a
# license that conforms to the Open Source Definition (Version 1.9)
# published by the Open Source Initiative.

# Please submit bugfixes or comments via http://bugs.opensuse.org/
#


Name:           mariadb-connector-odbc
Version:        3.0.2
Release:        3.23
Summary:        MariaDB ODBC Connector
License:        LGPL-2.1+
Group:          Productivity/Databases/Tools
Url:            https://downloads.mariadb.org/connector-odbc/
Source:         https://downloads.mariadb.org/interstitial/connector-odbc-%{version}/mariadb-connector-odbc-%{version}-ga-src.tar.gz
# signature is from copy/pasted stuff found on the download page, not actual file
Source1:        mariadb-connector-odbc-%{version}-ga-src.tar.gz.asc
Source2:        README
Source3:        sample_odbc.ini
Source4:        mariadb-connector-odbc-rpmlintrc
Patch1:         libreoffice_fixes.patch
Patch3:         missing_includes.patch
Patch5:         package_name.patch
Patch6:         DSN_names.patch
Patch7:         missing_libs.patch
Patch8:         nosoname.patch
BuildRequires:  cmake > 3.5.0
BuildRequires:  gcc-c++
# This is actually MariaDB -devel package(s)
BuildRequires:  libmariadb-devel
BuildRequires:  libmariadbprivate
BuildRequires:  openssl-devel
BuildRequires:  unixODBC-devel
Obsoletes:      MyODBC-unixODBC <= 5.1.9

%description
This package contains the MariaDB ODBC Connector to be used with unixODBC.

%prep
%setup -q -n mariadb-connector-odbc-%{version}-ga-src
%patch1 -p1
%patch3 -p1
%patch5 -p1
%patch6 -p1
%patch7 -p1
%patch8 -p1

%build
export CFLAGS="%{optflags} -std=gnu11"
%cmake \
  -DWITH_UNIXODBC=1 \
  -DWITH_OPENSSL=ON \
  -DMARIADB_LINK_DYNAMIC=1
%make_jobs

%install
%cmake_install
install -Dpm 0644 %{SOURCE2} %{SOURCE3} \
  %{buildroot}%{_docdir}/%{name}

%post   -p /sbin/ldconfig
%postun -p /sbin/ldconfig

%files
%doc COPYING
%{_libdir}/libmaodbc.so
%{_docdir}/%{name}/README
%{_docdir}/%{name}/sample_odbc.ini

%changelog
* Thu Jan  4 2018 adam.majer@suse.de
- libreoffice_fixes.patch: Fix crash with LibreOffice (bnc#938195)
- add mariadb-connector-odbc-rpmlintrc to ignore some
  rpmlint warnings
* Tue Dec 12 2017 mpluskal@suse.com
- Enable openssl support
- Honor optflags when building
* Tue Dec 12 2017 mvetter@suse.com
- Remove 'Provides', it is not a drop in replacement
  for MyODBC-unixODBC. Users will have to change .so file.
  Obsoletes is enough.
* Mon Dec 11 2017 adam.majer@suse.de
- Provide upgrade path for users of MyODBC-unixODBC
* Sun Nov 19 2017 mpluskal@suse.com
- Use more cmake macros
- Run spec-cleaner
* Fri Nov 17 2017 adam.majer@suse.de
- New upstream version 3.0.2
  * first stable version of MariaDB Connector/ODBC 3.0
  * fixed number of memory leaks
- Refreshed patches:
  * missing_includes.patch
  * package_name.patch
- Removed upstreamed patches:
  * fix_bool_return_types.patch
  * no_static_linking.patch
- missing_libs.patch: Add missing -lpthread dependency
- nosoname.patch: libmaodbc.so is an ODBC driver, not a normal
  library. Remove soname generation.
* Thu Jul 13 2017 adam.majer@suse.de
- New upstream version 2.0.15:
  * fix crash in ODBC Driver SQLExecDirect()
  * fix batch query with non-preparable statement crashed
  * fix backslash at the end of string in one of statements in
    multistatement query leads to error
- Changes in version 2.0.14:
  * SQLGetData now correctly handles UTF-16 surrogate pairs
  * Execution of 'ANALYZE TABLE' statement used to invalidate
    statement and connection handles
  * SQLGetData would not return SQL_NO_DATA for BLOB/TEXT columns
    if the buffer size is larger than the column data
  * Min and Max value for time data type were processed incorrectly
  * fixed Error in the SQLGetTypeInfo for WCHAR Types
  * SQLBulkOperations/SQLSetPos SQL_ADD would fail if TIMESTAMP
    column ignored
* Wed Mar 29 2017 adam.majer@suse.de
- Add sample_odbc.ini file to documentation directory.
* Thu Mar 23 2017 adam.majer@suse.de
- Initial package of MariaDB Connector/ODBC 2.0.13
- fix_bool_return_types.patch: use only supported data types
- missing_includes.patch: missing headers added
- no_static_linking.patch: dynamically link with the private
  symbols library.
- package_name.patch: set package name to SUSE package name
  so we don't have to move files around after install or change
  library names.
